@@ -28,13 +28,13 @@ class HUBTrainingSession:
     Attributes:
         model_id (str): Identifier for the YOLO model being trained.
         model_url (str): URL for the model in Ultralytics HUB.
-        rate_limits (Dict[str, int]): Rate limits for different API calls in seconds.
-        timers (Dict[str, Any]): Timers for rate limiting.
-        metrics_queue (Dict[str, Any]): Queue for the model's metrics.
-        metrics_upload_failed_queue (Dict[str, Any]): Queue for metrics that failed to upload.
+        rate_limits (dict[str, int]): Rate limits for different API calls in seconds.
+        timers (dict[str, Any]): Timers for rate limiting.
+        metrics_queue (dict[str, Any]): Queue for the model's metrics.
+        metrics_upload_failed_queue (dict[str, Any]): Queue for metrics that failed to upload.
         model (Any): Model data fetched from Ultralytics HUB.
         model_file (str): Path to the model file.
-        train_args (Dict[str, Any]): Arguments for training the model.
+        train_args (dict[str, Any]): Arguments for training the model.
         client (Any): Client for interacting with Ultralytics HUB.
         filename (str): Filename of the model.
 
@@ -98,7 +98,7 @@ class HUBTrainingSession:
 
         Args:
             identifier (str): Model identifier used to initialize the HUB training session.
-            args (Dict[str, Any], optional): Arguments for creating a new model if identifier is not a HUB model URL.
+            args (dict[str, Any], optional): Arguments for creating a new model if identifier is not a HUB model URL.
 
         Returns:
             session (HUBTrainingSession | None): An authenticated session or None if creation fails.
@@ -144,7 +144,7 @@ class HUBTrainingSession:
         Initialize a HUB training session with the specified model arguments.
 
         Args:
-            model_args (Dict[str, Any]): Arguments for creating the model, including batch size, epochs, image size,
+            model_args (dict[str, Any]): Arguments for creating the model, including batch size, epochs, image size,
                 etc.
 
         Returns:
