@@ -1,5 +1,7 @@
 # Ultralytics 🚀 AGPL-3.0 License - https://ultralytics.com/license
 
+from typing import Any
+
 from ultralytics.solutions.solutions import BaseSolution, SolutionAnnotator, SolutionResults
 from ultralytics.utils import LOGGER
 from ultralytics.utils.plotting import colors
@@ -32,7 +34,7 @@ class SecurityAlarm(BaseSolution):
         >>> results = security.process(frame)
     """
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs: Any) -> None:
         """
         Initialize the SecurityAlarm class with parameters for real-time object monitoring.
 
@@ -46,7 +48,7 @@ class SecurityAlarm(BaseSolution):
         self.to_email = ""
         self.from_email = ""
 
-    def authenticate(self, from_email: str, password: str, to_email: str):
+    def authenticate(self, from_email: str, password: str, to_email: str) -> None:
         """
         Authenticate the email server for sending alert notifications.
 
@@ -69,12 +71,12 @@ class SecurityAlarm(BaseSolution):
         self.to_email = to_email
         self.from_email = from_email
 
-    def send_email(self, im0, records: int = 5):
+    def send_email(self, im0, records: int = 5) -> None:
         """
         Send an email notification with an image attachment indicating the number of objects detected.
 
         Args:
-            im0 (numpy.ndarray): The input image or frame to be attached to the email.
+            im0 (np.ndarray): The input image or frame to be attached to the email.
             records (int, optional): The number of detected objects to be included in the email message.
 
         This method encodes the input image, composes the email message with details about the detection, and sends it
@@ -114,12 +116,12 @@ class SecurityAlarm(BaseSolution):
         except Exception as e:
             LOGGER.error(f"Failed to send email: {e}")
 
-    def process(self, im0):
+    def process(self, im0) -> SolutionResults:
         """
         Monitor the frame, process object detections, and trigger alerts if thresholds are exceeded.
 
         Args:
-            im0 (numpy.ndarray): The input image or frame to be processed and annotated.
+            im0 (np.ndarray): The input image or frame to be processed and annotated.
 
         Returns:
             (SolutionResults): Contains processed image `plot_im`, 'total_tracks' (total number of tracked objects) and
